@@ -1,5 +1,5 @@
 import uuid
-from datatime import datetime
+from datetime import datetime
 import sqlalchemy.types as types
 from sqlalchemy import Column, ForeignKey, String, DateTime
 from flask_sqlalchemy import SQLAlchemy as _SQLAlchemy, BaseQuery, Model as SAModel
